==> purpose-1.1-2-aarch64.pkg.tar.xz: usr/lib/cmake/KDEExperimentalPurpose/KDEExperimentalPurposeTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEExperimental::Purpose" for configuration "Release"
set_property(TARGET KDEExperimental::Purpose APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDEExperimental::Purpose PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5Purpose.so.5.22.0"
  IMPORTED_SONAME_RELEASE "libKF5Purpose.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDEExperimental::Purpose )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDEExperimental::Purpose "${_IMPORT_PREFIX}/lib/libKF5Purpose.so.5.22.0" )

# Import target "KDEExperimental::PurposeWidgets" for configuration "Release"
set_property(TARGET KDEExperimental::PurposeWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDEExperimental::PurposeWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Qml;KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5PurposeWidgets.so.5.22.0"
  IMPORTED_SONAME_RELEASE "libKF5PurposeWidgets.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDEExperimental::PurposeWidgets )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDEExperimental::PurposeWidgets "${_IMPORT_PREFIX}/lib/libKF5PurposeWidgets.so.5.22.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> purpose-1.2.1-1-aarch64.pkg.tar.xz: usr/lib/cmake/KDEExperimentalPurpose/KDEExperimentalPurposeTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEExperimental::Purpose" for configuration "Release"
set_property(TARGET KDEExperimental::Purpose APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDEExperimental::Purpose PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Network;KF5::ConfigCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5Purpose.so.5.39.0"
  IMPORTED_SONAME_RELEASE "libKF5Purpose.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDEExperimental::Purpose )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDEExperimental::Purpose "${_IMPORT_PREFIX}/lib/libKF5Purpose.so.5.39.0" )

# Import target "KDEExperimental::PurposeWidgets" for configuration "Release"
set_property(TARGET KDEExperimental::PurposeWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDEExperimental::PurposeWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Qml;KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5PurposeWidgets.so.5.39.0"
  IMPORTED_SONAME_RELEASE "libKF5PurposeWidgets.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDEExperimental::PurposeWidgets )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDEExperimental::PurposeWidgets "${_IMPORT_PREFIX}/lib/libKF5PurposeWidgets.so.5.39.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
